@@ -1,8 +1,9 @@
 import asyncio
 import json
+from ssl import SSLContext
 from inspect import isfunction
 from websockets import connect
-from websockets.protocol import State
+from websockets.legacy.protocol import State
 from websockets.exceptions import ConnectionClosed
 
 from inmation_api_client.eventemitter import EventEmitter
@@ -42,6 +43,7 @@ class WSClient(EventEmitter):
         self._subscribed_items = {}
         self.url = None
         self.options = None
+        self.ssl = None
         self.ioloop = ioloop or asyncio.get_event_loop()
         self.reconnect_counter = 0
 
@@ -91,20 +93,24 @@ class WSClient(EventEmitter):
 
             self._process_ready_state(self._ws.state)
 
-    async def connect(self, url, options):
+    async def connect(self, url, options, ssl=None):
         """ Connect to the WebSocket server.
         Args:
             url (str): URL of the WebSocket
             options (object): Options object
+            ssl (bool | SSLContext): Use secure websocket (ssl=None: Insecure, ssl=True: Secure, ssl=ssl.SSLContext object: Advanced SSL config)
         """
 
         if not isinstance(url, str):
             raise Error('A WebSocket URL is not specified in the configuration.')
         if not (isinstance(options, Options) or isinstance(options, dict)):
             raise Error('The <<options>> argument is required when establishing a connection.')
+        if not (isinstance(ssl, (bool, SSLContext)) or ssl is None):
+            raise Error('The <<ssl>> argument must be of type bool, SSLContext or None')
 
         self.url = url
         self.options = options
+        self.ssl = ssl
 
         if WSClient.DEBUG_LOG:
             logging.info('Connecting to: {}'.format(self.url))
@@ -113,7 +119,7 @@ class WSClient(EventEmitter):
         try:
             # Disable asynchronous context manager functionality
             # max_size = None disables the size limit of incoming messages
-            self._ws = await connect(self.url, close_timeout=options.tim or 10, loop=self.ioloop, max_size=None)
+            self._ws = await connect(self.url, close_timeout=options.tim or 10, loop=self.ioloop, max_size=None, ssl=self.ssl)
         except OSError as err:
             if err.strerror is not None:
                 con_err = err.strerror
@@ -146,12 +152,12 @@ class WSClient(EventEmitter):
         await asyncio.sleep(self._reconnect_delay_time)
 
         print('Re-connecting to: {} ...'.format(self.url))
-        await self.connect(self.url, self.options)
+        await self.connect(self.url, self.options, self.ssl)
 
         while True:
             if not self._connection_info.state_string == WSConnectionInfo.CONNECTEDSTRING \
                     and not self._connection_info.authenticated:
-                await self.connect(self.url, self.options)
+                await self.connect(self.url, self.options, self.ssl)
             else:
                 break
 
